@@ -1,3 +1,4 @@
+var after = require('after')
 var assert = require('assert')
 var Buffer = require('safe-buffer').Buffer
 var bytes = require('bytes')
@@ -157,19 +158,21 @@ describe('compression()', function () {
 
   it('should back-pressure when compressed', function (done) {
     var buf
+    var cb = after(2, done)
     var client
     var drained = false
     var resp
     var server = createServer({ threshold: 0 }, function (req, res) {
       resp = res
+
       res.on('drain', function () {
         drained = true
       })
+
       res.setHeader('Content-Type', 'text/plain')
       res.write('start')
       pressure()
     })
-    var wait = 2
 
     crypto.pseudoRandomBytes(1024 * 128, function (err, chunk) {
       if (err) return done(err)
@@ -177,24 +180,21 @@ describe('compression()', function () {
       pressure()
     })
 
-    function complete () {
-      if (--wait !== 0) return
-      assert.ok(drained)
-      done()
-    }
-
     function pressure () {
       if (!buf || !resp || !client) return
 
+      assert.ok(!drained)
+
       while (resp.write(buf) !== false) {
         resp.flush()
       }
 
       resp.on('drain', function () {
-        resp.write('end')
+        assert.ok(resp.write('end'))
         resp.end()
       })
-      resp.on('finish', complete)
+
+      resp.on('finish', cb)
       client.resume()
     }
 
@@ -205,7 +205,7 @@ describe('compression()', function () {
         client = res
         assert.equal(res.headers['content-encoding'], 'gzip')
         res.pause()
-        res.on('end', complete)
+        res.on('end', cb)
         pressure()
       })
       .end()
@@ -213,19 +213,21 @@ describe('compression()', function () {
 
   it('should back-pressure when uncompressed', function (done) {
     var buf
+    var cb = after(2, done)
     var client
     var drained = false
     var resp
     var server = createServer({ filter: function () { return false } }, function (req, res) {
       resp = res
+
       res.on('drain', function () {
         drained = true
       })
+
       res.setHeader('Content-Type', 'text/plain')
       res.write('start')
       pressure()
     })
-    var wait = 2
 
     crypto.pseudoRandomBytes(1024 * 128, function (err, chunk) {
       if (err) return done(err)
@@ -233,12 +235,6 @@ describe('compression()', function () {
       pressure()
     })
 
-    function complete () {
-      if (--wait !== 0) return
-      assert.ok(drained)
-      done()
-    }
-
     function pressure () {
       if (!buf || !resp || !client) return
 
@@ -247,10 +243,11 @@ describe('compression()', function () {
       }
 
       resp.on('drain', function () {
-        resp.write('end')
+        assert.ok(drained)
+        assert.ok(resp.write('end'))
         resp.end()
       })
-      resp.on('finish', complete)
+      resp.on('finish', cb)
       client.resume()
     }
 
@@ -261,7 +258,7 @@ describe('compression()', function () {
         client = res
         shouldNotHaveHeader('Content-Encoding')(res)
         res.pause()
-        res.on('end', complete)
+        res.on('end', cb)
         pressure()
       })
       .end()
